@@ -1,41 +1,14 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2004-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """
 Univention Package Database
 Python module for the package database
 """
 
+from __future__ import annotations
+
 import argparse
 import csv
 import os
@@ -49,25 +22,24 @@ import dns.resolver
 import pgdb
 
 import univention.config_registry
-import univention.uldap
 
 
 assert pgdb.paramstyle == 'pyformat'
 
-# TODO use FQDN or DN as system identifier instead of hostname?
-# TODO add <limit> parameter to sql_get* functions
-# TODO add <order> parameter to sql_get* functions to change/disable sort
+# TODO: use FQDN or DN as system identifier instead of hostname?
+# TODO: add <limit> parameter to sql_get* functions
+# TODO: add <order> parameter to sql_get* functions to change/disable sort
 # TODO: pkgdbu should not be able to create roles, instead do it as postgres from listener script as root
 
 
 def parse_options():
     """
     parse options and return <options> with
-            <options.debug>
-            <options.action>
-            <options.system>
-            <options.db_server>
-            set
+        <options.debug>
+        <options.action>
+        <options.system>
+        <options.db_server>
+        set
     """
     parser = argparse.ArgumentParser(add_help=False, description='Scan all packages in the local system and send this data to the database pkgdb.')
     actions = parser.add_argument_group('Actions', 'Select an action, default is --scan')
@@ -345,7 +317,7 @@ def sql_getall_packages_in_systems(cursor):
 def sql_get_systems_by_query(cursor, query):
     if not query:
         return []
-    sqlcmd = "SELECT sysname, sysversion, sysrole, to_char(scandate,'YYYY-MM-DD HH24:MI:SS'), ldaphostdn FROM systems WHERE " + query + " ORDER BY sysname"  # FIXME  # noqa: S608
+    sqlcmd = "SELECT sysname, sysversion, sysrole, to_char(scandate,'YYYY-MM-DD HH24:MI:SS'), ldaphostdn FROM systems WHERE " + query + " ORDER BY sysname"  # FIXME:  # noqa: S608
     return sql_select(cursor, sqlcmd)
 
 
@@ -353,9 +325,9 @@ def sql_get_packages_in_systems_by_query(cursor, query, join_systems, limit=None
     if not query:
         return []
     if join_systems:
-        sqlcmd = "SELECT sysname, pkgname, vername, to_char(packages_on_systems.scandate, 'YYYY-MM-DD HH24:MI:SS'), inststatus, selectedstate, inststate, currentstate FROM packages_on_systems JOIN systems USING(sysname) WHERE " + query  # FIXME  # noqa: S608
+        sqlcmd = "SELECT sysname, pkgname, vername, to_char(packages_on_systems.scandate, 'YYYY-MM-DD HH24:MI:SS'), inststatus, selectedstate, inststate, currentstate FROM packages_on_systems JOIN systems USING(sysname) WHERE " + query  # FIXME:  # noqa: S608
     else:
-        sqlcmd = "SELECT sysname, pkgname, vername, to_char(packages_on_systems.scandate, 'YYYY-MM-DD HH24:MI:SS'), inststatus, selectedstate, inststate, currentstate FROM packages_on_systems WHERE " + query  # FIXME  # noqa: S608
+        sqlcmd = "SELECT sysname, pkgname, vername, to_char(packages_on_systems.scandate, 'YYYY-MM-DD HH24:MI:SS'), inststatus, selectedstate, inststate, currentstate FROM packages_on_systems WHERE " + query  # FIXME:  # noqa: S608,
 
     if orderby:
         sqlcmd += " ORDER BY %s" % (orderby)
